@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import logging
+from collections import namedtuple
 from zeep import Client, xsd
 from zeep.helpers import serialize_object
 
@@ -12,6 +13,7 @@ class CorreosHandler:
     """
         Handler to send shipping payload to Correos Chile.
     """
+
     def __init__(self, wsdl_url=api_settings.CORREOS_CHILE['EXECUTE_WSDL'],
                  user=api_settings.CORREOS_CHILE['USER'],
                  password=api_settings.CORREOS_CHILE['PASSWORD']):
@@ -26,32 +28,28 @@ class CorreosHandler:
 
     def get_shipping_label(self, shipping_id):
         raise NotImplementedError(
-        'get_shipping_label is not a method implemented for CorreosHandler')
-
+            'get_shipping_label is not a method implemented for CorreosHandler')
 
     def get_default_payload(self, instance):
         """
             This method generates by default all the necessary data with
             an appropriate structure for Correos Chile courier.
-        """
-        try:
-            address = instance.address
-            payload = {
-                'wms_reference': instance.wms_reference,
-                'recipient_name': instance.customer_full_name,
-                'recipient_address': f'{address.street} {address.number}',
-                'recipient_postal_code': address.commune.code,
-                'recipient_commune': address.commune.name,
-                'recipient_rut': instance.customer_rut,
-                'recipient_contact': instance.customer_full_name,
-                'recipient_phone': instance.customer_phone
-            }
 
-            logger.debug(payload)
-            return payload
-        except Exception as error:
-            logger.error(error)
-            return False
+            Returns default payload or AttributeError Exception.
+        """
+        payload = {
+            'reference': instance.reference,
+            'recipient_name': instance.customer.full_name,
+            'recipient_address': f'{instance.address.street} {instance.address.number}',
+            'recipient_postal_code': instance.commune.code,
+            'recipient_commune': instance.commune.name,
+            'recipient_rut': instance.customer.rut,
+            'recipient_contact': instance.customer.full_name,
+            'recipient_phone': instance.customer.phone
+        }
+
+        logger.debug(payload)
+        return payload
 
     def create_shipping(self, data):
         """
@@ -92,7 +90,7 @@ class CorreosHandler:
             NumeroTotalPiezas='1',
             Kilos='1',
             Volumen='0',
-            NumeroReferencia=f"{api_settings.CORREOS_CHILE['COD_REF']} - {data['wms_reference']}",
+            NumeroReferencia=f"{api_settings.CORREOS_CHILE['COD_REF']} - {data['reference']}",
             ImporteReembolso='0',
             ImporteValorDeclarado='0',
             TipoPortes=api_settings.CORREOS_CHILE['TYPE_POR'],
@@ -120,7 +118,6 @@ class CorreosHandler:
             logger.error(error)
             return False
 
-
     def get_tracking(self, identifier):
         """
             This method obtain a detail a shipping of Correos Chile.
